@@ -711,7 +711,7 @@ void CSoundFile::SetDspEffects(uint32 DSPMask)
 {
 #ifdef ENABLE_ASM
 #ifndef NO_REVERB
-	if(!(GetProcSupport() & PROCSUPPORT_MMX)) DSPMask &= ~SNDDSP_REVERB;
+	if(!(GetRealProcSupport() & PROCSUPPORT_MMX)) DSPMask &= ~SNDDSP_REVERB;
 #endif
 #endif
 	m_MixerSettings.DSPMask = DSPMask;
@@ -1163,7 +1163,6 @@ PlayBehaviourSet CSoundFile::GetDefaultPlaybackBehaviour(MODTYPE type)
 		break;
 
 	case MOD_TYPE_MOD:
-		playBehaviour.set(kMODSampleSwap);
 		playBehaviour.set(kRowDelayWithNoteDelay);
 		break;
 
